@@ -114,6 +114,7 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
         }
 #   endif
 
+#   if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
     // Hide Qt bug 'Assertion when reading an icns file'
     // https://bugreports.qt.io/browse/QTBUG-45537
     // Remove after Qt fix will be released
@@ -121,6 +122,13 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     {
         type = QtDebugMsg;
     }
+#   endif
+
+    // Hide anything that starts with QMacCGContext
+    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QMacCGContext::")))
+    {
+        type = QtDebugMsg;
+    }
 
     // See issue #568
     if (msg.contains(QStringLiteral("Error receiving trust for a CA certificate")))
