@@ -9,7 +9,7 @@
  **  This source code is part of the Valentina project, a pattern making
  **  program, whose allow create and modeling patterns of clothing.
  **  Copyright (C) 2013-2015 Valentina project
- **  <https://bitbucket.org/dismine/valentina> All Rights Reserved.
+ **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
  **
  **  Valentina is free software: you can redistribute it and/or modify
  **  it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@
 #include <QSettings>
 #include <QTableWidgetItem>
 #include <QtNumeric>
+#include <QMenu>
 
 #define DIALOG_MAX_FORMULA_HEIGHT 64
 
@@ -89,14 +90,13 @@ DialogIncrements::DialogIncrements(VContainer *data, VPattern *doc, QWidget *par
     formulaBaseHeightPC = ui->plainTextEditFormulaPC->height();
     ui->plainTextEditFormulaPC->installEventFilter(this);
 
-    qApp->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
+    VAbstractApplication::VApp()->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
 
     qCDebug(vDialog, "Showing variables.");
     ShowUnits();
 
-    const bool freshCall = true;
-    FillIncrements(freshCall);
-    FillPreviewCalculations(freshCall);
+    FillIncrements();
+    FillPreviewCalculations();
     FillLengthsLines();
     FillLengthLinesAngles();
     FillLengthsCurves();
@@ -107,16 +107,18 @@ DialogIncrements::DialogIncrements(VContainer *data, VPattern *doc, QWidget *par
     connect(this->doc, &VPattern::FullUpdateFromFile, this, &DialogIncrements::FullUpdateFromFile);
 
     ui->tabWidget->setCurrentIndex(0);
-    ui->lineEditName->setValidator( new QRegularExpressionValidator(QRegularExpression(
-                                                                        QLatin1String("^$|")+NameRegExp()), this));
-    ui->lineEditNamePC->setValidator( new QRegularExpressionValidator(QRegularExpression(
-                                                                        QLatin1String("^$|")+NameRegExp()), this));
+    auto validator = new QRegularExpressionValidator(QRegularExpression(QStringLiteral("^$|")+NameRegExp()), this);
+    ui->lineEditName->setValidator(validator);
+    ui->lineEditNamePC->setValidator(validator);
 
     connect(ui->tableWidgetIncrement, &QTableWidget::itemSelectionChanged, this,
             &DialogIncrements::ShowIncrementDetails);
     connect(ui->tableWidgetPC, &QTableWidget::itemSelectionChanged, this,
             &DialogIncrements::ShowIncrementDetails);
 
+    ui->toolButtonAdd->setMenu(InitVarTypeMenu(ui->toolButtonAdd->menu(), true /*increments tab*/));
+    ui->toolButtonAddPC->setMenu(InitVarTypeMenu(ui->toolButtonAddPC->menu(), false /*preview calculations tab*/));
+
     connect(ui->toolButtonAdd, &QToolButton::clicked, this, &DialogIncrements::AddIncrement);
     connect(ui->toolButtonAddPC, &QToolButton::clicked, this, &DialogIncrements::AddIncrement);
     connect(ui->toolButtonRemove, &QToolButton::clicked, this, &DialogIncrements::RemoveIncrement);
@@ -179,15 +181,15 @@ DialogIncrements::DialogIncrements(VContainer *data, VPattern *doc, QWidget *par
 /**
  * @brief FillIncrementTable fill data for increment table
  */
-void DialogIncrements::FillIncrements(bool freshCall)
+void DialogIncrements::FillIncrements()
 {
-    FillIncrementsTable(ui->tableWidgetIncrement, data->DataIncrements(), false, freshCall);
+    FillIncrementsTable(ui->tableWidgetIncrement, data->DataIncrementsWithSeparators(), false);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogIncrements::FillPreviewCalculations(bool freshCall)
+void DialogIncrements::FillPreviewCalculations()
 {
-    FillIncrementsTable(ui->tableWidgetPC, data->DataIncrements(), true, freshCall);
+    FillIncrementsTable(ui->tableWidgetPC, data->DataIncrementsWithSeparators(), true);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -207,10 +209,12 @@ void DialogIncrements::FillTable(const QMap<QString, T> &varTable, QTableWidget
 
         QTableWidgetItem *item = new QTableWidgetItem(i.key());
         item->setTextAlignment(Qt::AlignLeft);
-        item->setFont(QFont("Times", 12, QFont::Bold));
+        QFont font = item->font();
+        font.setBold(true);
+        item->setFont(font);
         table->setItem(currentRow, 0, item);
 
-        item = new QTableWidgetItem(qApp->LocaleToString(length));
+        item = new QTableWidgetItem(VAbstractApplication::VApp()->LocaleToString(length));
         item->setTextAlignment(Qt::AlignHCenter);
         table->setItem(currentRow, 1, item);
     }
@@ -264,7 +268,7 @@ void DialogIncrements::FillAnglesCurves()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogIncrements::ShowUnits()
 {
-    const QString unit = UnitsToStr(qApp->patternUnit());
+    const QString unit = UnitsToStr(VAbstractValApplication::VApp()->patternUnits());
 
     ShowHeaderUnits(ui->tableWidgetIncrement, 1, unit);// calculated value
     ShowHeaderUnits(ui->tableWidgetIncrement, 2, unit);// formula
@@ -285,17 +289,19 @@ void DialogIncrements::ShowHeaderUnits(QTableWidget *table, int column, const QS
     SCASSERT(table != nullptr)
 
     const QString header = table->horizontalHeaderItem(column)->text();
-    const QString unitHeader = QString("%1 (%2)").arg(header, unit);
+    const QString unitHeader = QStringLiteral("%1 (%2)").arg(header, unit);
     table->horizontalHeaderItem(column)->setText(unitHeader);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogIncrements::AddCell(QTableWidget *table, const QString &text, int row, int column, int aligment, bool ok)
+QTableWidgetItem * DialogIncrements::AddCell(QTableWidget *table, const QString &text, int row, int column,
+                                             int aligment, bool ok)
 {
     SCASSERT(table != nullptr)
 
     QTableWidgetItem *item = new QTableWidgetItem(text);
     item->setTextAlignment(aligment);
+    item->setToolTip(text);
 
     // set the item non-editable (view only), and non-selectable
     Qt::ItemFlags flags = item->flags();
@@ -310,6 +316,21 @@ void DialogIncrements::AddCell(QTableWidget *table, const QString &text, int row
     }
 
     table->setItem(row, column, item);
+
+    return item;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QTableWidgetItem* DialogIncrements::AddSeparatorCell(QTableWidget *table, const QString &text, int row, int column,
+                                                     int aligment, bool ok)
+{
+    QTableWidgetItem *item = AddCell(table, text, row, column, aligment, ok);
+
+    QFont itemFont = item->font();
+    itemFont.setBold(true);
+    itemFont.setItalic(true);
+    item->setFont(itemFont);
+    return item;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -319,7 +340,8 @@ QString DialogIncrements::GetCustomName() const
     QString name;
     do
     {
-        name = CustomIncrSign + qApp->TrVars()->InternalVarToUser(increment_) + QString().number(num);
+        name = CustomIncrSign + VAbstractApplication::VApp()->TrVars()->InternalVarToUser(increment_) +
+                QString().number(num);
         num++;
     } while (not data->IsUnique(name));
     return name;
@@ -340,7 +362,8 @@ QString DialogIncrements::ClearIncrementName(const QString &name) const
 //---------------------------------------------------------------------------------------------------------------------
 bool DialogIncrements::EvalIncrementFormula(const QString &formula, bool fromUser, VContainer *data, QLabel *label)
 {
-    const QString postfix = UnitsToStr(qApp->patternUnit());//Show unit in dialog lable (cm, mm or inch)
+    const QString postfix =
+            UnitsToStr(VAbstractValApplication::VApp()->patternUnits());//Show unit in dialog lable (cm, mm or inch)
     if (formula.isEmpty())
     {
         label->setText(tr("Error") + " (" + postfix + "). " + tr("Empty field."));
@@ -355,7 +378,8 @@ bool DialogIncrements::EvalIncrementFormula(const QString &formula, bool fromUse
             // Replace line return character with spaces for calc if exist
             if (fromUser)
             {
-                f = qApp->TrVars()->FormulaFromUser(formula, qApp->Settings()->GetOsSeparator());
+                f = VAbstractApplication::VApp()->TrVars()
+                        ->FormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
             }
             else
             {
@@ -371,7 +395,7 @@ bool DialogIncrements::EvalIncrementFormula(const QString &formula, bool fromUse
                 return false;
             }
 
-            label->setText(qApp->LocaleToString(result) + QChar(QChar::Space) + postfix);
+            label->setText(VAbstractApplication::VApp()->LocaleToString(result) + QChar(QChar::Space) + postfix);
             label->setToolTip(tr("Value"));
             return true;
         }
@@ -553,6 +577,33 @@ void DialogIncrements::EnableDetails(QTableWidget *table, bool enabled)
         ui->plainTextEditDescriptionPC->setEnabled(enabled);
         ui->plainTextEditFormulaPC->setEnabled(enabled);
     }
+
+    if (table->rowCount() > 0)
+    {
+        const QTableWidgetItem *nameField = table->item(table->currentRow(), 0);
+        SCASSERT(nameField != nullptr)
+        QSharedPointer<VIncrement> incr = data->GetVariable<VIncrement>(nameField->text());
+        const bool isSeparator = incr->GetIncrementType() == IncrementType::Separator;
+
+        if (table == ui->tableWidgetIncrement)
+        {
+            ui->labelCalculated->setVisible(not isSeparator);
+            ui->labelCalculatedValue->setVisible(not isSeparator);
+            ui->labelFormula->setVisible(not isSeparator);
+            ui->plainTextEditFormula->setVisible(not isSeparator);
+            ui->pushButtonGrow->setVisible(not isSeparator);
+            ui->toolButtonExpr->setVisible(not isSeparator);
+        }
+        else if (table == ui->tableWidgetPC)
+        {
+            ui->labelCalculatedPC->setVisible(not isSeparator);
+            ui->labelCalculatedValuePC->setVisible(not isSeparator);
+            ui->labelFormulaPC->setVisible(not isSeparator);
+            ui->plainTextEditFormulaPC->setVisible(not isSeparator);
+            ui->pushButtonGrowPC->setVisible(not isSeparator);
+            ui->toolButtonExprPC->setVisible(not isSeparator);
+        }
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -585,7 +636,7 @@ bool DialogIncrements::IncrementUsed(const QString &name) const
 {
     const QVector<VFormulaField> expressions = doc->ListExpressions();
 
-    for(auto field : expressions)
+    for(auto &field : expressions)
     {
         if (field.expression.indexOf(name) != -1)
         {
@@ -681,7 +732,9 @@ void DialogIncrements::ShowTableIncrementDetails(QTableWidget *table)
         EvalIncrementFormula(incr->GetFormula(), false, incr->GetData(), labelCalculatedValue);
         plainTextEditFormula->blockSignals(true);
 
-        QString formula = VTranslateVars::TryFormulaToUser(incr->GetFormula(), qApp->Settings()->GetOsSeparator());
+        QString formula =
+                VTranslateVars::TryFormulaToUser(incr->GetFormula(),
+                                                 VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 
         plainTextEditFormula->setPlainText(formula);
         plainTextEditFormula->blockSignals(false);
@@ -692,6 +745,74 @@ void DialogIncrements::ShowTableIncrementDetails(QTableWidget *table)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QMenu *DialogIncrements::InitVarTypeMenu(QMenu *menu, bool incrementTab)
+{
+    if (menu == nullptr)
+    {
+        menu = new QMenu(this);
+    }
+    else
+    {
+        menu->clear();
+    }
+
+    QAction *action = menu->addAction(tr("Increment"));
+    action->setData(incrementTab); // Increments tab
+    connect(action, &QAction::triggered, this, &DialogIncrements::AddIncrement);
+
+    action = menu->addAction(tr("Separator"));
+    action->setData(incrementTab); // Increments tab
+    connect(action, &QAction::triggered, this, &DialogIncrements::AddSeparator);
+
+    return menu;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogIncrements::AddNewIncrement(IncrementType type)
+{
+    qCDebug(vDialog, "Add new increment");
+
+    bool incrementMode = true;
+    if (auto *action = qobject_cast<QAction *>(sender()))
+    {
+        incrementMode = action->data().toBool();
+    }
+    else if (auto *button = qobject_cast<QToolButton *>(sender()))
+    {
+        incrementMode = button == ui->toolButtonAdd;
+    }
+    else
+    {
+        return;
+    }
+
+    QTableWidget *table = incrementMode ? ui->tableWidgetIncrement : ui->tableWidgetPC;
+
+    const QString name = GetCustomName();
+    qint32 currentRow = -1;
+
+    if (table->currentRow() == -1)
+    {
+        currentRow = table->rowCount();
+        incrementMode ? doc->AddEmptyIncrement(name, type) : doc->AddEmptyPreviewCalculation(name, type);
+    }
+    else
+    {
+        currentRow  = table->currentRow()+1;
+        const QTableWidgetItem *nameField = table->item(table->currentRow(), 0);
+
+        incrementMode ? doc->AddEmptyIncrementAfter(nameField->text(), name, type) :
+                        doc->AddEmptyPreviewCalculationAfter(nameField->text(), name, type);
+    }
+
+    hasChanges = true;
+    LocalUpdateTree();
+
+    table->selectRow(currentRow);
+    table->repaint(); // Force repain to fix paint artifacts on Mac OS X
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief FullUpdateFromFile update information in tables form file
@@ -700,6 +821,9 @@ void DialogIncrements::FullUpdateFromFile()
 {
     hasChanges = false;
 
+    const int incrementRow = ui->tableWidgetIncrement->currentRow();
+    const int pcRow = ui->tableWidgetPC->currentRow();
+
     ui->tableWidgetLines->clearContents();
     ui->tableWidgetSplines->clearContents();
     ui->tableWidgetAnglesCurves->clearContents();
@@ -719,6 +843,9 @@ void DialogIncrements::FullUpdateFromFile()
 
     search->RefreshList(ui->lineEditFind->text());
     searchPC->RefreshList(ui->lineEditFindPC->text());
+
+    ui->tableWidgetIncrement->selectRow(incrementRow);
+    ui->tableWidgetPC->selectRow(pcRow);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -736,7 +863,7 @@ void DialogIncrements::RefreshPattern()
         const int row = ui->tableWidgetIncrement->currentRow();
         const int rowPC = ui->tableWidgetPC->currentRow();
 
-        doc->LiteParseTree(Document::LiteParse);
+        doc->LiteParseTree(Document::FullLiteParse);
 
         ui->tableWidgetIncrement->blockSignals(true);
         ui->tableWidgetIncrement->selectRow(row);
@@ -753,7 +880,7 @@ void DialogIncrements::RefreshPattern()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogIncrements::FillIncrementsTable(QTableWidget *table,
                                            const QMap<QString, QSharedPointer<VIncrement> > &increments,
-                                           bool takePreviewCalculations, bool freshCall)
+                                           bool takePreviewCalculations)
 {
     SCASSERT(table != nullptr)
 
@@ -765,10 +892,10 @@ void DialogIncrements::FillIncrementsTable(QTableWidget *table,
     //Sorting QHash by id
     for (i = increments.constBegin(); i != increments.constEnd(); ++i)
     {
-        QSharedPointer<VIncrement> incr = i.value();
+        const QSharedPointer<VIncrement>& incr = i.value();
         if (takePreviewCalculations == incr->IsPreviewCalculation())
         {
-            map.insert(incr->getIndex(), i.key());
+            map.insert(incr->GetIndex(), i.key());
         }
     }
 
@@ -778,23 +905,35 @@ void DialogIncrements::FillIncrementsTable(QTableWidget *table,
     while (iMap.hasNext())
     {
         iMap.next();
-        QSharedPointer<VIncrement> incr = increments.value(iMap.value());
-        currentRow++;
+        const QSharedPointer<VIncrement> &incr = increments.value(iMap.value());
+        ++currentRow;
 
-        AddCell(table, incr->GetName(), currentRow, 0, Qt::AlignVCenter); // name
-        AddCell(table, qApp->LocaleToString(*incr->GetValue()), currentRow, 1,
-                Qt::AlignHCenter | Qt::AlignVCenter, incr->IsFormulaOk()); // calculated value
+        if (incr->GetType() == VarType::Increment)
+        {
+            AddCell(table, incr->GetName(), currentRow, 0, Qt::AlignVCenter); // name
+            AddCell(table, VAbstractApplication::VApp()->
+                    LocaleToString(*incr->GetValue()), currentRow, 1, Qt::AlignCenter,
+                    incr->IsFormulaOk()); // calculated value
 
-        QString formula = VTranslateVars::TryFormulaToUser(incr->GetFormula(), qApp->Settings()->GetOsSeparator());
+            QString formula =
+                    VTranslateVars::TryFormulaToUser(incr->GetFormula(),
+                                                     VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 
-        AddCell(table, formula, currentRow, 2, Qt::AlignVCenter); // formula
+            AddCell(table, formula, currentRow, 2, Qt::AlignVCenter); // formula
+
+            if (table->columnSpan(currentRow, 1) > 1)
+            {
+                table->setSpan(currentRow, 1, 1, 1);
+            }
+        }
+        else if (incr->GetType() == VarType::IncrementSeparator)
+        {
+            AddSeparatorCell(table, incr->GetName(), currentRow, 0, Qt::AlignVCenter); // name
+            AddCell(table, incr->GetDescription(), currentRow, 1, Qt::AlignCenter); // description
+            table->setSpan(currentRow, 1, 1, 2);
+        }
     }
 
-    if (freshCall)
-    {
-        table->resizeColumnsToContents();
-        table->resizeRowsToContents();
-    }
     table->horizontalHeader()->setStretchLastSection(true);
     table->blockSignals(false);
 }
@@ -805,60 +944,13 @@ void DialogIncrements::FillIncrementsTable(QTableWidget *table,
  */
 void DialogIncrements::AddIncrement()
 {
-    qCDebug(vDialog, "Add new increment");
+    AddNewIncrement(IncrementType::Increment);
+}
 
-    QToolButton *button = qobject_cast<QToolButton *>(sender());
-    QTableWidget *table = nullptr;
-
-    if (button == ui->toolButtonAdd)
-    {
-        table = ui->tableWidgetIncrement;
-    }
-    else if (button == ui->toolButtonAddPC)
-    {
-        table = ui->tableWidgetPC;
-    }
-    else
-    {
-        return;
-    }
-
-    const QString name = GetCustomName();
-    qint32 currentRow = -1;
-
-    if (table->currentRow() == -1)
-    {
-        currentRow = table->rowCount();
-
-        if (button == ui->toolButtonAdd)
-        {
-            doc->AddEmptyIncrement(name);
-        }
-        else if (button == ui->toolButtonAddPC)
-        {
-            doc->AddEmptyPreviewCalculation(name);
-        }
-    }
-    else
-    {
-        currentRow  = table->currentRow()+1;
-        const QTableWidgetItem *nameField = table->item(table->currentRow(), 0);
-
-        if (button == ui->toolButtonAdd)
-        {
-            doc->AddEmptyIncrementAfter(nameField->text(), name);
-        }
-        else if (button == ui->toolButtonAddPC)
-        {
-            doc->AddEmptyPreviewCalculationAfter(nameField->text(), name);
-        }
-    }
-
-    hasChanges = true;
-    LocalUpdateTree();
-
-    table->selectRow(currentRow);
-    table->repaint(); // Force repain to fix paint artifacts on Mac OS X
+//---------------------------------------------------------------------------------------------------------------------
+void DialogIncrements::AddSeparator()
+{
+    AddNewIncrement(IncrementType::Separator);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -905,22 +997,14 @@ void DialogIncrements::RemoveIncrement()
     hasChanges = true;
     LocalUpdateTree();
 
-    if (table->rowCount() > 0)
-    {
-        table->selectRow(0);
-    }
-    else
-    {
-        EnableDetails(table, false);
-    }
-
+    table->rowCount() > 0 ? table->selectRow(0) : EnableDetails(table, false);
     table->repaint(); // Force repain to fix paint artifacts on Mac OS X
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogIncrements::MoveUp()
 {
-    QToolButton *button = qobject_cast<QToolButton *>(sender());
+    auto *button = qobject_cast<QToolButton *>(sender());
 
     QTableWidget *table = nullptr;
 
@@ -1046,7 +1130,7 @@ void DialogIncrements::SaveIncrName(const QString &text)
         QString name = newName;
         do
         {
-            name = name + QLatin1String("_") + QString().number(num);
+            name = name + '_' + QString().number(num);
             num++;
         } while (not data->IsUnique(name));
         newName = name;
@@ -1152,7 +1236,7 @@ void DialogIncrements::SaveIncrFormula()
     {
         QTableWidgetItem *result = table->item(row, 1);
         //Show unit in dialog lable (cm, mm or inch)
-        const QString postfix = UnitsToStr(qApp->patternUnit());
+        const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits());
         labelCalculatedValue->setText(result->text() + QChar(QChar::Space) +postfix);
         return;
     }
@@ -1160,12 +1244,17 @@ void DialogIncrements::SaveIncrFormula()
     if (text.isEmpty())
     {
         //Show unit in dialog lable (cm, mm or inch)
-        const QString postfix = UnitsToStr(qApp->patternUnit());
+        const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits());
         labelCalculatedValue->setText(tr("Error") + " (" + postfix + "). " + tr("Empty field."));
         return;
     }
 
     QSharedPointer<VIncrement> incr = data->GetVariable<VIncrement>(nameField->text());
+    if (incr->GetIncrementType() == IncrementType::Separator)
+    {
+        return;
+    }
+
     if (not EvalIncrementFormula(text, true, incr->GetData(), labelCalculatedValue))
     {
         return;
@@ -1173,7 +1262,8 @@ void DialogIncrements::SaveIncrFormula()
 
     try
     {
-        const QString formula = qApp->TrVars()->FormulaFromUser(text, qApp->Settings()->GetOsSeparator());
+        const QString formula = VAbstractApplication::VApp()->TrVars()
+                ->FormulaFromUser(text, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         doc->SetIncrementFormula(nameField->text(), formula);
     }
     catch (qmu::QmuParserError &e) // Just in case something bad will happen
@@ -1230,15 +1320,15 @@ void DialogIncrements::DeployFormula()
     {
         plainTextEditFormula->setFixedHeight(DIALOG_MAX_FORMULA_HEIGHT);
         //Set icon from theme (internal for Windows system)
-        pushButtonGrow->setIcon(QIcon::fromTheme("go-next",
-                                                  QIcon(":/icons/win.icon.theme/16x16/actions/go-next.png")));
+        pushButtonGrow->setIcon(QIcon::fromTheme(QStringLiteral("go-next"),
+                                                 QIcon(":/icons/win.icon.theme/16x16/actions/go-next.png")));
     }
     else
     {
        plainTextEditFormula->setFixedHeight(baseHeight);
        //Set icon from theme (internal for Windows system)
-       pushButtonGrow->setIcon(QIcon::fromTheme("go-down",
-                                                 QIcon(":/icons/win.icon.theme/16x16/actions/go-down.png")));
+       pushButtonGrow->setIcon(QIcon::fromTheme(QStringLiteral("go-down"),
+                                                QIcon(":/icons/win.icon.theme/16x16/actions/go-down.png")));
     }
 
     // I found that after change size of formula field, it was filed for angle formula, field for formula became black.
@@ -1291,17 +1381,17 @@ void DialogIncrements::Fx()
     dialog->setWindowTitle(tr("Edit increment"));
     incrementMode ? dialog->SetIncrementsMode() : dialog->SetPreviewCalculationsMode();
 
-    dialog->SetFormula(qApp->TrVars()->TryFormulaFromUser(plainTextEditFormula->toPlainText(),
-                                                          qApp->Settings()->GetOsSeparator()));
-    const QString postfix = UnitsToStr(qApp->patternUnit(), true);
+    dialog->SetFormula(VAbstractApplication::VApp()->TrVars()
+                       ->TryFormulaFromUser(plainTextEditFormula->toPlainText(),
+                                            VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+    const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
     dialog->setPostfix(postfix);//Show unit in dialog lable (cm, mm or inch)
 
     if (dialog->exec() == QDialog::Accepted)
     {
         // Fix the bug #492. https://bitbucket.org/dismine/valentina/issues/492/valentina-crashes-when-add-an-increment
         // Because of the bug need to take QTableWidgetItem twice time. Previous update "killed" the pointer.
-        const QTableWidgetItem *nameField = table->item(row, 0);
-        doc->SetIncrementFormula(nameField->text(), dialog->GetFormula());
+        doc->SetIncrementFormula(table->item(row, 0)->text(), dialog->GetFormula());
 
         hasChanges = true;
         LocalUpdateTree();
@@ -1334,6 +1424,10 @@ void DialogIncrements::changeEvent(QEvent *event)
     {
         // retranslate designer form (single inheritance approach)
         ui->retranslateUi(this);
+
+        ui->toolButtonAdd->setMenu(InitVarTypeMenu(ui->toolButtonAdd->menu(), true /*increments tab*/));
+        ui->toolButtonAddPC->setMenu(InitVarTypeMenu(ui->toolButtonAddPC->menu(), false /*preview calculations tab*/));
+
         FullUpdateFromFile();
     }
     // remember to call base class implementation
@@ -1350,7 +1444,7 @@ bool DialogIncrements::eventFilter(QObject *object, QEvent *event)
             QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
             if ((keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
             {
-                if (qApp->Settings()->GetOsSeparator())
+                if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
                 {
                     textEdit->insert(QLocale().decimalPoint());
                 }
@@ -1362,12 +1456,9 @@ bool DialogIncrements::eventFilter(QObject *object, QEvent *event)
             }
         }
     }
-    else
-    {
-        // pass the event on to the parent class
-        return DialogTool::eventFilter(object, event);
-    }
-    return false;// pass the event to the widget
+
+    // pass the event on to the parent class
+    return DialogTool::eventFilter(object, event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1386,7 +1477,7 @@ void DialogIncrements::showEvent(QShowEvent *event)
     }
     // do your init stuff here
 
-    const QSize sz = qApp->Settings()->GetIncrementsDialogSize();
+    const QSize sz = VAbstractApplication::VApp()->Settings()->GetIncrementsDialogSize();
     if (not sz.isEmpty())
     {
         resize(sz);
@@ -1403,7 +1494,7 @@ void DialogIncrements::resizeEvent(QResizeEvent *event)
     // dialog creating, which would
     if (isInitialized)
     {
-        qApp->Settings()->SetIncrementsDialogSize(size());
+        VAbstractApplication::VApp()->Settings()->SetIncrementsDialogSize(size());
     }
     DialogTool::resizeEvent(event);
 }
