@@ -138,8 +138,7 @@ bool VDxfEngine::begin(QPaintDevice *pdev)
 //---------------------------------------------------------------------------------------------------------------------
 bool VDxfEngine::end()
 {
-    const bool res = input->fileExport(m_binary);
-    return res;
+    return input->fileExport(m_binary);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -611,6 +610,12 @@ void VDxfEngine::SetYScale(const qreal &yscale)
     m_yscale = yscale;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QString VDxfEngine::ErrorString() const
+{
+    return QString::fromStdString(input->ErrorString());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wswitch-default")
@@ -668,7 +673,7 @@ bool VDxfEngine::ExportToAAMA(const QVector<VLayoutPiece> &details)
 
     for(auto detail : details)
     {
-        dx_ifaceBlock *detailBlock = new dx_ifaceBlock();
+        auto *detailBlock = new dx_ifaceBlock();
 
         QString blockName = detail.GetName();
         if (m_version <= DRW::AC1009)
@@ -691,7 +696,7 @@ bool VDxfEngine::ExportToAAMA(const QVector<VLayoutPiece> &details)
 
         input->AddBlock(detailBlock);
 
-        DRW_Insert *insert = new DRW_Insert();
+        auto *insert = new DRW_Insert();
         insert->name = blockName.toStdString();
         insert->layer = '1';
 
@@ -714,7 +719,7 @@ void VDxfEngine::ExportAAMAOutline(dx_ifaceBlock *detailBlock, const VLayoutPiec
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportAAMADraw(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    if (not detail.IsHideMainPath() && not detail.IsSeamAllowanceBuiltIn())
+    if (detail.IsSeamAllowance() && not detail.IsHideMainPath() && not detail.IsSeamAllowanceBuiltIn())
     {
         if (DRW_Entity *e = AAMAPolygon(detail.GetMappedContourPoints(), QChar('8'), true))
         {
@@ -869,7 +874,7 @@ bool VDxfEngine::ExportToASTM(const QVector<VLayoutPiece> &details)
 
     for(auto detail : details)
     {
-        dx_ifaceBlock *detailBlock = new dx_ifaceBlock();
+        auto *detailBlock = new dx_ifaceBlock();
 
         QString blockName = detail.GetName();
         if (m_version <= DRW::AC1009)
@@ -894,7 +899,7 @@ bool VDxfEngine::ExportToASTM(const QVector<VLayoutPiece> &details)
 
         input->AddBlock(detailBlock);
 
-        DRW_Insert *insert = new DRW_Insert();
+        auto *insert = new DRW_Insert();
         insert->name = blockName.toStdString();
         insert->layer = '1';
 
@@ -927,7 +932,7 @@ void VDxfEngine::ExportASTMPieceBoundary(dx_ifaceBlock *detailBlock, const VLayo
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportASTMSewLine(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    if (not detail.IsHideMainPath() && not detail.IsSeamAllowanceBuiltIn())
+    if (detail.IsSeamAllowance() && not detail.IsHideMainPath() && not detail.IsSeamAllowanceBuiltIn())
     {
         QVector<QPointF> sewLine = detail.GetMappedContourPoints();
 
