@@ -139,6 +139,7 @@ void VLayoutExporter::ExportToSVG(QGraphicsScene *scene) const
 
     QPainter painter;
     painter.begin(&generator);
+    painter.translate(-m_offset.x(), -m_offset.y());
     painter.translate(m_margins.left(), m_margins.top());
     painter.setRenderHint(QPainter::Antialiasing, true);
     painter.setPen(m_pen);
@@ -374,6 +375,18 @@ auto VLayoutExporter::SupportPDFConversion() -> bool
     return res;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QPointF VLayoutExporter::offset() const
+{
+    return m_offset;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::SetOffset(QPointF newOffset)
+{
+    m_offset = newOffset;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief PdfToPs use external tool "pdftops" for converting pdf too eps or ps format.
