@@ -49,8 +49,8 @@ extern const QString APP_VERSION_STR;
 // Change version number in projectversion.cpp too.
 // Synchronize valentina.nsi
 
-#define VER_FILEVERSION             0,7,47
-#define VER_FILEVERSION_STR         "0.7.47\0"
+#define VER_FILEVERSION             0,7,49
+#define VER_FILEVERSION_STR         "0.7.49\0"
 
 #define V_PRERELEASE // Mark prerelease builds
 
@@ -66,7 +66,7 @@ extern const QString APP_VERSION_STR;
 //#define VER_ORIGINALFILENAME_STR  "valentina.exe" // Defined in program
 //#define VER_PRODUCTNAME_STR       "Valentina" // Defined in program
 
-#define VER_COMPANYDOMAIN_STR       "valentinaproject.bitbucket.io"
+#define VER_COMPANYDOMAIN_STR       "smart-pattern.com.ua"
 
 QString compilerString();
 QString buildCompatibilityString();
