@@ -197,17 +197,6 @@ void VAbstractApplication::WinAttachConsole()
 }
 #endif
 
-//---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief getSettings hide settings constructor.
- * @return pointer to class for acssesing to settings in ini file.
- */
-VCommonSettings *VAbstractApplication::Settings()
-{
-    SCASSERT(settings != nullptr)
-    return settings;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractApplication::LoadTranslation(const QString &locale)
 {
@@ -326,9 +315,3 @@ QFileDialog::Options VAbstractApplication::NativeFileDialog(QFileDialog::Options
 
     return options;
 }
-
-//---------------------------------------------------------------------------------------------------------------------
-auto VAbstractApplication::VApp() -> VAbstractApplication *
-{
-    return qobject_cast<VAbstractApplication*>(QCoreApplication::instance());
-}
