@@ -86,6 +86,57 @@ const QString VToolSeamAllowance::AttrTopPin               = QStringLiteral("top
 const QString VToolSeamAllowance::AttrBottomPin            = QStringLiteral("bottomPin");
 const QString VToolSeamAllowance::AttrPiecePriority        = QStringLiteral("priority");
 
+namespace
+{
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T>
+auto FixLabelPins(T itemData, const QMap<quint32, quint32> &mappedPins) -> T
+{
+    itemData.SetCenterPin(mappedPins.value(itemData.CenterPin(), NULL_ID));
+    itemData.SetTopLeftPin(mappedPins.value(itemData.TopLeftPin(), NULL_ID));
+    itemData.SetBottomRightPin(mappedPins.value(itemData.BottomRightPin(), NULL_ID));
+    return itemData;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T>
+auto FixGrainlinePins(T itemData, const QMap<quint32, quint32> &mappedPins) -> T
+{
+    itemData.SetCenterPin(mappedPins.value(itemData.CenterPin(), NULL_ID));
+    itemData.SetTopPin(mappedPins.value(itemData.TopPin(), NULL_ID));
+    itemData.SetBottomPin(mappedPins.value(itemData.BottomPin(), NULL_ID));
+    return itemData;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DuplicatePins(const QVector<quint32> &pins, const VToolSeamAllowanceInitData &initData) -> QMap<quint32, quint32>
+{
+    QMap<quint32, quint32> newPins;
+    for(auto p : pins)
+    {
+        QSharedPointer<VPointF> pin = initData.data->GeometricObject<VPointF>(p);
+
+        auto *tool = qobject_cast<VAbstractNode *>(VAbstractPattern::getTool(p));
+        SCASSERT(tool != nullptr)
+
+        VToolPinInitData initNodeData;
+        initNodeData.id = initData.data->AddGObject(new VPointF(*pin));
+        initNodeData.pointId = pin->getIdObject();
+        initNodeData.idObject = NULL_ID; // piece id
+        initNodeData.doc = initData.doc;
+        initNodeData.data = initData.data;
+        initNodeData.parse = Document::FullParse;
+        initNodeData.typeCreation = Source::FromTool;
+        initNodeData.drawName = initData.drawName;
+        initNodeData.idTool = tool->GetIdTool();
+
+        VToolPin::Create(initNodeData);
+        newPins.insert(p, initNodeData.id);
+    }
+    return newPins;
+}
+}  // namespace
+
 //---------------------------------------------------------------------------------------------------------------------
 VToolSeamAllowance *VToolSeamAllowance::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
                                                VAbstractPattern *doc, VContainer *data)
@@ -192,7 +243,7 @@ VToolSeamAllowance *VToolSeamAllowance::Duplicate(const QPointer<DialogTool> &di
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolSeamAllowance *VToolSeamAllowance::Duplicate(VToolSeamAllowanceInitData &initData)
+auto VToolSeamAllowance::Duplicate(VToolSeamAllowanceInitData &initData) -> VToolSeamAllowance *
 {
     VPiece dupDetail = initData.detail;
 
@@ -201,9 +252,14 @@ VToolSeamAllowance *VToolSeamAllowance::Duplicate(VToolSeamAllowanceInitData &in
     dupDetail.SetCustomSARecords(DuplicateCustomSARecords(initData.detail.GetCustomSARecords(), initData,
                                                           replacements));
     dupDetail.SetInternalPaths(DuplicateInternalPaths(initData.detail.GetInternalPaths(), initData));
-    dupDetail.SetPins(DuplicatePins(initData.detail.GetPins(), initData));
     dupDetail.SetPlaceLabels(DuplicatePlaceLabels(initData.detail.GetPlaceLabels(), initData));
 
+    const QMap<quint32, quint32> mappedPins = DuplicatePins(initData.detail.GetPins(), initData);
+    dupDetail.SetPins(mappedPins.values().toVector());
+    dupDetail.SetPatternPieceData(FixLabelPins(initData.detail.GetPatternPieceData(), mappedPins));
+    dupDetail.SetPatternInfo(FixLabelPins(initData.detail.GetPatternInfo(), mappedPins));
+    dupDetail.SetGrainlineGeometry(FixGrainlinePins(initData.detail.GetGrainlineGeometry(), mappedPins));
+
     initData.detail = dupDetail;
     return VToolSeamAllowance::Create(initData);
 }
@@ -654,6 +710,13 @@ void VToolSeamAllowance::UpdatePatternInfo()
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VToolSeamAllowance::UpdatePassmarks()
+{
+    const VPiece detail = VAbstractTool::data.GetPiece(m_id);
+    m_passmarks->setPath(detail.PassmarksPath(getData()));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VToolDetail::UpdateGrainline updates the grain line item
@@ -876,14 +939,12 @@ void VToolSeamAllowance::paint(QPainter *painter, const QStyleOptionGraphicsItem
 //---------------------------------------------------------------------------------------------------------------------
 QRectF VToolSeamAllowance::boundingRect() const
 {
-    if (m_mainPathRect.isNull())
+    if (m_pieceBoundingRect.isNull())
     {
         return QGraphicsPathItem::boundingRect();
     }
-    else
-    {
-        return m_mainPathRect;
-    }
+
+    return m_pieceBoundingRect;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1214,7 +1275,6 @@ VToolSeamAllowance::VToolSeamAllowance(const VToolSeamAllowanceInitData &initDat
     : VInteractiveTool(initData.doc, initData.data, initData.id),
       QGraphicsPathItem(parent),
       m_mainPath(),
-      m_mainPathRect(),
       m_sceneDetails(initData.scene),
       m_drawName(initData.drawName),
       m_seamAllowance(new VNoBrushScalePathItem(this)),
@@ -1240,6 +1300,7 @@ VToolSeamAllowance::VToolSeamAllowance(const VToolSeamAllowanceInitData &initDat
     connect(this, &VToolSeamAllowance::ChoosedTool, m_sceneDetails, &VMainGraphicsScene::ChoosedItem);
     connect(m_sceneDetails, &VMainGraphicsScene::EnableToolMove, this, &VToolSeamAllowance::EnableToolMove);
     connect(m_sceneDetails, &VMainGraphicsScene::ItemSelection, this, &VToolSeamAllowance::ToolSelectionType);
+    connect(m_sceneDetails, &VMainGraphicsScene::UpdatePassmarks, this, &VToolSeamAllowance::UpdatePassmarks);
 
     ConnectOutsideSignals();
 }
@@ -1310,7 +1371,6 @@ void VToolSeamAllowance::RefreshGeometry(bool updateChildren)
             || not detail.IsSeamAllowance() || detail.IsSeamAllowanceBuiltIn())
     {
         m_mainPath = QPainterPath();
-        m_mainPathRect = QRectF();
         m_seamAllowance->setBrush(QBrush(Qt::Dense7Pattern));
         path = futurePath.result();
     }
@@ -1319,7 +1379,6 @@ void VToolSeamAllowance::RefreshGeometry(bool updateChildren)
         m_seamAllowance->setBrush(QBrush(Qt::NoBrush)); // Disable if the main path was hidden
         // need for returning a bounding rect when main path is not visible
         m_mainPath = futurePath.result();
-        m_mainPathRect = m_mainPath.controlPointRect();
         path = QPainterPath();
     }
 
@@ -1339,10 +1398,14 @@ void VToolSeamAllowance::RefreshGeometry(bool updateChildren)
         path.addPath(detail.SeamAllowancePath(futureSeamAllowance.result()));
         path.setFillRule(Qt::OddEvenFill);
         m_seamAllowance->setPath(path);
+
+        m_pieceBoundingRect = m_seamAllowance->path().controlPointRect();
     }
     else
     {
         m_seamAllowance->setPath(QPainterPath());
+
+        m_pieceBoundingRect = m_mainPath.controlPointRect();
     }
 
     if (VAbstractApplication::VApp()->IsAppInGUIMode())
@@ -2108,36 +2171,6 @@ QVector<quint32> VToolSeamAllowance::DuplicateInternalPaths(const QVector<quint3
     return newPaths;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-QVector<quint32> VToolSeamAllowance::DuplicatePins(const QVector<quint32> &pins,
-                                                   const VToolSeamAllowanceInitData &initData)
-{
-    QVector<quint32> newPins;
-    newPins.reserve(pins.size());
-    for(auto p : pins)
-    {
-        QSharedPointer<VPointF> pin = initData.data->GeometricObject<VPointF>(p);
-
-        VAbstractNode *tool = qobject_cast<VAbstractNode *>(VAbstractPattern::getTool(p));
-        SCASSERT(tool != nullptr)
-
-        VToolPinInitData initNodeData;
-        initNodeData.id = initData.data->AddGObject(new VPointF(*pin));
-        initNodeData.pointId = pin->getIdObject();
-        initNodeData.idObject = NULL_ID; // piece id
-        initNodeData.doc = initData.doc;
-        initNodeData.data = initData.data;
-        initNodeData.parse = Document::FullParse;
-        initNodeData.typeCreation = Source::FromTool;
-        initNodeData.drawName = initData.drawName;
-        initNodeData.idTool = tool->GetIdTool();
-
-        VToolPin::Create(initNodeData);
-        newPins.append(initNodeData.id);
-    }
-    return newPins;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 QVector<quint32> VToolSeamAllowance::DuplicatePlaceLabels(const QVector<quint32> &placeLabels,
                                                           const VToolSeamAllowanceInitData &initData)
