@@ -9,7 +9,7 @@
  **  This source code is part of the Valentina project, a pattern making
  **  program, whose allow create and modeling patterns of clothing.
  **  Copyright (C) 2015 Valentina project
- **  <https://bitbucket.org/dismine/valentina> All Rights Reserved.
+ **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
  **
  **  Valentina is free software: you can redistribute it and/or modify
  **  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 
 #include "tst_vspline.h"
 #include "../vgeometry/vspline.h"
-#include "../vmisc/logging.h"
 
 #include <QtTest>
 
@@ -666,7 +665,8 @@ void TST_VSpline::GetSegmentPoints_issue767()
     points.append(QPointF(4214.980535433111, 2269.448333408385));
     points.append(QPointF(4214.980535433071, 2235.242494488189));
 
-    const QVector<QPointF> res = VAbstractCurve::GetSegmentPoints(points, begin, end, false);
+    QString error;
+    const QVector<QPointF> res = VAbstractCurve::GetSegmentPoints(points, begin, end, false, error);
 
     QVector<QPointF> origPoints;
     origPoints.append(QPointF(3964.650771379471, 3212.2173150777817));
